from astropy.io import fits
from astropy import wcs
import galsim
import os
import yaml

from SingleEpochImage import SingleEpochImage
from InjectionCatalog import InjectionCatalog
from InputCatalogs import SimCat
from Grid import RectGrid
from config import parse_args

# img_file = 'CSST_MSC_MS_SCI_20240617065639_20240617065909_100000000_24_L0_1.fits'
img_file = 'CSST_MSC_MS_SCI_20240617065639_20240617065909_100000000_23_L0_1.fits' # null-weight test image

args = parse_args()
if args.config_dir is None:
    args.config_dir = ''
args.config_dir = os.path.abspath(args.config_dir)
args.config_file = os.path.join(args.config_dir, args.config_file)
print(args.config_file)
with open(args.config_file, "r") as stream:
    try:
        config = yaml.safe_load(stream)
        for key, value in config.items():
            print (key + " : " + str(value))
    except yaml.YAMLError as exc:
        print(exc)

image = SingleEpochImage(config=config, filepath=img_file)
# print(image.ramin, image.ramax, image.u_area, image.ra_boundary_cross)
inject_cat = InjectionCatalog(image=image)
inject_cat.generate_positions(config=config)
input_cat = SimCat(config=config, chip=image.chip, nobjects=inject_cat.nobjects)
print(inject_cat.pos, inject_cat.nobjects)
image.inject_objects(pos=inject_cat.pos, cat=input_cat)
image.save_injected_img()